==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Checkbox/Checkbox.base.js <==
import '../node_modules/core-js/modules/es.array.index-of.js';
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Model, Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';
import { Icon } from '../Icon/index.js';
import { Label } from '../Label/index.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var CheckboxBase = function (_BaseComponent) {
  _inherits(CheckboxBase, _BaseComponent);

  var _super = _createSuper(CheckboxBase);

  function CheckboxBase() {
    var _this;

    _classCallCheck(this, CheckboxBase);

    _this = _super.apply(this, arguments);
    _this.internalValue = _this.checked || _this.defaultChecked;
    _this.isIndeterminate = _this.indeterminate || _this.defaultIndeterminate;
    return _this;
  }

  _createClass(CheckboxBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          title = this.title,
          label = this.label;
      return h("div", {
        "class": classNames.root
      }, [h("input", _mergeJSXProps([{
        "attrs": {
          "id": "Checkbox".concat(this.uid)
        },
        "class": classNames.input
      }, this.$attrs, {
        "attrs": {
          "disabled": this.disabled,
          "type": "checkbox"
        },
        "on": {
          "input": this.onInput
        }
      }])), h(Label, {
        "class": classNames.label,
        "attrs": {
          "for": "Checkbox".concat(this.uid)
        }
      }, [h("div", {
        "class": classNames.checkbox
      }, [h(Icon, {
        "attrs": {
          "icon-name": "CheckMark"
        },
        "class": classNames.checkmark
      })]), (label || this.$slots["default"]) && h("span", {
        "class": classNames.text,
        "attrs": {
          "title": title
        }
      }, [this.$slots["default"] || label])])]);
    }
  }, {
    key: "onValueChanged",
    value: function onValueChanged(value) {
      this.$emit('input', value);
    }
  }, {
    key: "onInput",
    value: function onInput() {
      if (this.disabled) return;

      if (this.isIndeterminate) {
        this.internalValue = this.defaultChecked;
        this.isIndeterminate = false;
      } else {
        this.internalValue = !this.internalValue;
      }
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          disabled = this.disabled,
          isIndeterminate = this.isIndeterminate,
          internalValue = this.internalValue,
          boxSide = this.boxSide;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        disabled: disabled,
        indeterminate: isIndeterminate,
        checked: internalValue,
        reversed: boxSide !== 'start',
        isUsingCustomLabelRender: true
      });
    }
  }]);

  return CheckboxBase;
}(BaseComponent);

__decorate([Model('input', {
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "checked", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "defaultChecked", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "indeterminate", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "defaultIndeterminate", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "required", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], CheckboxBase.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], CheckboxBase.prototype, "title", void 0);

__decorate([Prop({
  type: String,
  "default": 'start',
  validator: function validator(v) {
    return ['start', 'end'].indexOf(v) > -1;
  }
}), __metadata("design:type", String)], CheckboxBase.prototype, "boxSide", void 0);

__decorate([Watch('internalValue'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean]), __metadata("design:returntype", void 0)], CheckboxBase.prototype, "onValueChanged", null);

CheckboxBase = __decorate([Component], CheckboxBase);

export { CheckboxBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Checkbox/Checkbox.base.js <==
import 'core-js/modules/es.array.index-of';
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Model, Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { Icon } from '../Icon/index.js';
import { Label } from '../Label/index.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var CheckboxBase = function (_BaseComponent) {
  _inherits(CheckboxBase, _BaseComponent);

  var _super = _createSuper(CheckboxBase);

  function CheckboxBase() {
    var _this;

    _classCallCheck(this, CheckboxBase);

    _this = _super.apply(this, arguments);
    _this.internalValue = _this.checked || _this.defaultChecked;
    _this.isIndeterminate = _this.indeterminate || _this.defaultIndeterminate;
    return _this;
  }

  _createClass(CheckboxBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          title = this.title,
          label = this.label;
      return h("div", {
        "class": classNames.root
      }, [h("input", _mergeJSXProps([{
        "attrs": {
          "id": "Checkbox".concat(this.uid)
        },
        "class": classNames.input
      }, this.$attrs, {
        "attrs": {
          "disabled": this.disabled,
          "type": "checkbox"
        },
        "on": {
          "input": this.onInput
        }
      }])), h(Label, {
        "class": classNames.label,
        "attrs": {
          "for": "Checkbox".concat(this.uid)
        }
      }, [h("div", {
        "class": classNames.checkbox
      }, [h(Icon, {
        "attrs": {
          "icon-name": "CheckMark"
        },
        "class": classNames.checkmark
      })]), (label || this.$slots.default) && h("span", {
        "class": classNames.text,
        "attrs": {
          "title": title
        }
      }, [this.$slots.default || label])])]);
    }
  }, {
    key: "onValueChanged",
    value: function onValueChanged(value) {
      this.$emit('input', value);
    }
  }, {
    key: "onInput",
    value: function onInput() {
      if (this.disabled) return;

      if (this.isIndeterminate) {
        this.internalValue = this.defaultChecked;
        this.isIndeterminate = false;
      } else {
        this.internalValue = !this.internalValue;
      }
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          disabled = this.disabled,
          isIndeterminate = this.isIndeterminate,
          internalValue = this.internalValue,
          boxSide = this.boxSide;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        disabled: disabled,
        indeterminate: isIndeterminate,
        checked: internalValue,
        reversed: boxSide !== 'start',
        isUsingCustomLabelRender: true
      });
    }
  }]);

  return CheckboxBase;
}(BaseComponent);

__decorate([Model('input', {
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "checked", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "defaultChecked", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "indeterminate", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "defaultIndeterminate", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "required", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], CheckboxBase.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], CheckboxBase.prototype, "title", void 0);

__decorate([Prop({
  type: String,
  default: 'start',
  validator: function validator(v) {
    return ['start', 'end'].indexOf(v) > -1;
  }
}), __metadata("design:type", String)], CheckboxBase.prototype, "boxSide", void 0);

__decorate([Watch('internalValue'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean]), __metadata("design:returntype", void 0)], CheckboxBase.prototype, "onValueChanged", null);

CheckboxBase = __decorate([Component], CheckboxBase);

export { CheckboxBase };
